@@ -3,9 +3,11 @@ test_that("Postal code bounding box is the same as regions", {
   # https://github.com/aleksanderbl29/dawaR/issues/100
   # https://github.com/aleksanderbl29/geodk/issues/1
 
-  regioner <- dawaR::get_map_data("regioner") |>
+  skip_on_cran()
+
+  regioner <- get_map_data("regioner") |>
     sf::st_bbox(dk)
-  postnumre <- dawaR::get_map_data("postnumre") |>
+  postnumre <- get_map_data("postnumre") |>
     sf::st_bbox(postnumre)
 
   expect_equal(regioner, postnumre)
